@@ -35,11 +35,12 @@ class SwaggerInterfaceDocHandler(BaseHandler):
                   },
                   "servers": [
                       {
-                          "url": 'http://{}:{}/'.format(options.outside_screen_ip, options.port),
+                          "url": 'http://{}:{}/'.format(options.outside_screen_ip,
+                                                        options.outside_screen_port if options.outside_screen_port else options.port),
                           "description": ''
                       }
                   ],
-                  "host": "{}:{}/".format(options.outside_screen_ip, options.port),
+                  "host": "{}:{}/".format(options.outside_screen_ip, options.outside_screen_port if options.outside_screen_port else options.port),
                   "paths": paths}
 
         self.original = True
