@@ -2,90 +2,31 @@ import importlib
 import random
 import uuid
 
-import tornado.options
+from tornado.options import options
 
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
 
 
-async def post(path, data=None,
-               base_url=tornado.options.options.data_server,
-               result_type="json", pack=False, **kwargs):
+async def common_request(method, path, params=None, data=None, json=None, base_url=options.data_server,
+                         result_type="json", pack=False, connect_config=None, **kwargs):
     try:
-        aiohttp = importlib.import_module("aiohttp")
+        httpx = importlib.import_module("httpx")
     except ImportError as e:
-        raise Exception(f"aiohttp is not exist,run:pip install aiohttp==3.8.3")
-
-    project_name = tornado.options.options.project_name.encode("utf-8")
-    flag = kwargs.pop("flag", True)
-    if flag:
-        if not kwargs.get("headers"):
-            kwargs.update({"headers": {
-                "Content-Type": "application/json",
-                "Project-Name": project_name,
-                "Request-Id": uuid.uuid1().hex
-            }})
-        else:
-            kwargs["headers"].update({"Project-Name": project_name})
-    else:
-        if not kwargs.get("headers"):
-            kwargs.update({"headers": {
-                "Project-Name": project_name,
-                "Request-Id": uuid.uuid1().hex
-            }})
-        else:
-            kwargs["headers"].update({"Project-Name": project_name})
-    async with aiohttp.ClientSession() as session:
-        flag = kwargs.pop("flag", True)
-        if flag:
-            async with session.post(base_url + path, json=data, **kwargs) as resp:
-                if result_type == "json":
-                    result = await resp.json()
-                    if not pack:
-                        if result.get("status") == "00000":
-                            result = result.get("data")
-                        else:
-                            message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
-                            raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-                elif result_type == "text":
-                    result = await resp.text()
-                else:
-                    result = await resp.content.read()
-                return result
-        else:
-            async with session.post(base_url + path, data=data, **kwargs) as resp:
-                if result_type == "json":
-                    result = await resp.json()
-                    if not pack:
-                        if result.get("status") == "00000":
-                            result = result.get("data")
-                        else:
-                            message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
-                            raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-                elif result_type == "text":
-                    result = await resp.text()
-                else:
-                    result = await resp.content.read()
-                return result
-
-
-async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
-              **kwargs):
-    try:
-        aiohttp = importlib.import_module("aiohttp")
-    except ImportError as e:
-        raise Exception(f"aiohttp is not exist,run:pip install aiohttp==3.8.3")
-    project_name = tornado.options.options.project_name.encode("utf-8")
+        raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+    project_name = options.project_name.encode("utf-8")
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
             "Project-Name": project_name,
             "Request-Id": uuid.uuid1().hex
         }})
     else:
-        kwargs["headers"].update({"Project-Name": project_name})
-
-    async with aiohttp.ClientSession() as session:
-        async with session.get(base_url + path, params=params, **kwargs) as resp:
+        kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
+    if not connect_config or not isinstance(connect_config, dict):
+        connect_config = dict()
+    with httpx.AsyncClient(**connect_config) as session:
+        async with session.request(method.upper(), url=base_url + path, params=params, json=json, data=data,
+                                   **kwargs) as resp:
             if result_type == "json":
                 result = await resp.json()
                 if not pack:
@@ -95,22 +36,51 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
                         message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
                         raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
             elif result_type == "text":
-                result = await resp.text()
+                result = await resp.text
             else:
                 result = await resp.content.read()
             return result
 
 
+async def post(path, data=None,
+               base_url=options.data_server,
+               result_type="json", pack=False, **kwargs):
+    flag = kwargs.pop("flag", True)
+    if flag:
+        return await common_request("POST", path=path, json=data, base_url=base_url,
+                                    result_type=result_type, pack=pack, **kwargs)
+    else:
+        return await common_request("POST", path=path, data=data, base_url=base_url,
+                                    result_type=result_type, pack=pack, **kwargs)
+
+
+async def get(path, params=None, base_url=options.data_server, result_type="json", pack=False,
+              **kwargs):
+    return await common_request("GET", path=path, params=params, base_url=base_url,
+                                result_type=result_type, pack=pack, **kwargs)
+
+
+async def put(path, params=None, data=None, json=None, base_url=options.data_server, result_type="json", pack=False,
+              **kwargs):
+    return await common_request("PUT", path=path, params=params, data=data, json=json, base_url=base_url,
+                                result_type=result_type, pack=pack, **kwargs)
+
+
+async def delete(path, params=None, data=None, json=None, base_url=options.data_server, result_type="json", pack=False,
+                 **kwargs):
+    return await common_request("DELETE", path=path, params=params, data=data, json=json, base_url=base_url,
+                                result_type=result_type, pack=pack, **kwargs)
+
+
 def sync_common_request(method, path, params=None, data=None, json=None, base_url=None, result_type="json",
                         pack=False, connect_config=None, **kwargs):
     try:
-        requests = importlib.import_module("requests")
-        requests_adapters = importlib.import_module("requests.adapters")
+        httpx = importlib.import_module("httpx")
     except ImportError as e:
-        raise Exception(f"requests is not exist,run:pip install requests==2.27.1")
-    project_name = tornado.options.options.project_name.encode("utf-8")
+        raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+    project_name = options.project_name.encode("utf-8")
     if not base_url:
-        base_url = tornado.options.options.data_server
+        base_url = options.data_server
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
             "Project-Name": project_name,
@@ -118,53 +88,31 @@ def sync_common_request(method, path, params=None, data=None, json=None, base_ur
         }})
     else:
         kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
-    if not connect_config:
-        connect_config = {
-            "pool_connections": 10,
-            "pool_maxsize": 10,
-            "max_retries": 0,
-            "pool_block": False
-        }
-    s = requests.session()
-    if connect_config and isinstance(connect_config, dict):
-        adapter = requests_adapters.HTTPAdapter(**connect_config)
-        s.mount(prefix="http", adapter=adapter)
-        s.mount(prefix="https", adapter=adapter)
-    try:
-        if method == "GET":
-            res = s.get(base_url + path, params=params, data=data, json=json, **kwargs)
-        elif method == "POST":
-            res = s.post(base_url + path, params=params, data=data, json=json, **kwargs)
-        elif method == "PUT":
-            res = s.put(base_url + path, params=params, data=data, json=json, **kwargs)
-        elif method == "PATCH":
-            res = s.patch(base_url + path, params=params, data=data, json=json, **kwargs)
-        elif method == "DELETE":
-            res = s.delete(base_url + path, params=params, data=data, json=json, **kwargs)
-        else:
-            raise Exception(f"method={method} is not allowed")
-    except Exception as e:
-        raise e
-    finally:
-        s.close()
-    if result_type == "json":
-        res = res.json()
-        if not pack:
-            if res.get("status") == "00000":
-                res = res.get("data")
+    if not connect_config or not isinstance(connect_config, dict):
+        connect_config = dict()
+    with httpx.Client(**connect_config) as session:
+        try:
+            res = session.request(method.upper(), url=base_url + path, params=params, data=data, json=json, **kwargs)
+            if result_type == "json":
+                res = res.json()
+                if not pack:
+                    if res.get("status") == "00000":
+                        res = res.get("data")
+                    else:
+                        message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                        raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
+            elif result_type == "text":
+                res = res.text
             else:
-                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
-                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-    elif result_type == "text":
-        res = res.text
-    else:
-        res = res.content
-    return res
+                res = res.content
+            return res
+        except Exception as e:
+            raise e
 
 
 def sync_get(path, params=None, base_url=None, result_type="json", pack=False, connect_config=None, **kwargs):
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     res = sync_common_request(method="GET", path=path, params=params, base_url=base_url,
                               result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
     return res
@@ -175,7 +123,7 @@ def sync_post(path, data=None,
               result_type="json", pack=False, connect_config=None, **kwargs):
     flag = kwargs.pop("flag", True)
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     if flag:
         res = sync_common_request(method="POST", path=path, json=data, base_url=base_url,
                                   result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
@@ -189,7 +137,7 @@ def sync_post(path, data=None,
 def sync_patch(path, params=None, data=None, json=None, base_url=None,
                result_type="json", pack=False, connect_config=None, **kwargs):
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     res = sync_common_request(method="PATCH", path=path, params=params, data=data, json=json, base_url=base_url,
                               result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
     return res
@@ -198,7 +146,7 @@ def sync_patch(path, params=None, data=None, json=None, base_url=None,
 def sync_put(path, params=None, data=None, json=None, base_url=None,
              result_type="json", pack=False, connect_config=None, **kwargs):
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     res = sync_common_request(method="PATCH", path=path, params=params, data=data, json=json, base_url=base_url,
                               result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
     return res
@@ -207,7 +155,7 @@ def sync_put(path, params=None, data=None, json=None, base_url=None,
 def sync_delete(path, params=None, data=None, json=None, base_url=None,
                 result_type="json", pack=False, connect_config=None, **kwargs):
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     res = sync_common_request(method="DELETE", path=path, params=params, data=data, json=json, base_url=base_url,
                               result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
     return res
@@ -238,11 +186,11 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
 
 
 def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
-    base_url = tornado.options.options.data_server
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
 
-    if tornado.options.options.running_env != "local":
+    if options.running_env != "local":
 
         res = eureka_request(path=path, return_type=return_type, method="GET", data=data, app_name=app_name, pack=pack,
                              **kwargs)
@@ -254,10 +202,10 @@ def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE",
 
 
 def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=False, **kwargs):
-    base_url = tornado.options.options.data_server
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.running_env != "local":
+    if options.running_env != "local":
         import json
         res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data),
                              app_name=app_name,
@@ -270,7 +218,7 @@ def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE",
 
 
 def nacos_service_instance(service_name, namespace, clusters=None, group_name=None):
-    server_addresses = tornado.options.options.nacos_config.get("server_addresses")
+    server_addresses = options.nacos_config.get("server_addresses")
     try:
         nacos = importlib.import_module("nacos")
     except ImportError as e:
@@ -289,10 +237,10 @@ def nacos_service_instance(service_name, namespace, clusters=None, group_name=No
 
 def nacos_get(path, params=None, service_name=None, namespace="public", clusters=None, group_name=None,
               pack=False, return_type="json", **kwargs):
-    base_url = tornado.options.options.data_server
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.running_env != "local":
+    if options.running_env != "local":
         service_instance = nacos_service_instance(service_name=service_name,
                                                   namespace=namespace, clusters=clusters, group_name=group_name)
         base_url = f'http://{service_instance.get("ip")}:{service_instance.get("port")}'
@@ -303,10 +251,10 @@ def nacos_get(path, params=None, service_name=None, namespace="public", clusters
 
 def nacos_post(path, data=None, service_name=None, namespace="public", clusters=None, group_name=None,
                pack=False, return_type="json", **kwargs):
-    base_url = tornado.options.options.data_server
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.running_env != "local":
+    if options.running_env != "local":
         service_instance = nacos_service_instance(service_name=service_name,
                                                   namespace=namespace, clusters=clusters, group_name=group_name)
         base_url = f'http://{service_instance.get("ip")}:{service_instance.get("port")}'
@@ -316,20 +264,20 @@ def nacos_post(path, data=None, service_name=None, namespace="public", clusters=
 
 
 def common_get(path, params=None, service_name=None, namespace="public", clusters=None, group_name=None,
-               pack=False, return_type="json", connect_config=None, **kwargs):
-    base_url = tornado.options.options.data_server
+               pack=False, return_type="json", connect_config=None, request_type="request", **kwargs):
+    base_url = options.data_server
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.request_type == "request":
+    if request_type == "request":
         res = sync_get(path=path, params=params, base_url=base_url, result_type=return_type, pack=pack,
                        connect_config=connect_config, **kwargs)
         return res
-    elif tornado.options.options.request_type == "eureka":
+    elif request_type == "eureka":
         res = eureka_get(path=path, data=params, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
         return res
-    elif tornado.options.options.request_type == "nacos":
+    elif request_type == "nacos":
         res = nacos_get(path=path, params=params, service_name=service_name, namespace=namespace, clusters=clusters,
                         group_name=group_name, pack=pack, return_type=return_type, **kwargs)
         return res
@@ -338,20 +286,20 @@ def common_get(path, params=None, service_name=None, namespace="public", cluster
 
 
 def common_post(path, data=None, service_name=None, namespace="public", clusters=None, group_name=None,
-                pack=False, return_type="json", connect_config=None, **kwargs):
-    base_url = tornado.options.options.data_server
+                pack=False, return_type="json", connect_config=None, request_type="request", **kwargs):
+    base_url = options.data_server
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.request_type == "request":
+    if request_type == "request":
         res = sync_post(path=path, data=data, base_url=base_url, result_type=return_type, pack=pack,
                         connect_config=connect_config, **kwargs)
         return res
-    elif tornado.options.options.request_type == "eureka":
+    elif request_type == "eureka":
         res = eureka_post(path=path, data=data, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
         return res
-    elif tornado.options.options.request_type == "nacos":
+    elif request_type == "nacos":
         res = nacos_post(path=path, data=data, service_name=service_name, namespace=namespace, clusters=clusters,
                          group_name=group_name,
                          pack=pack, return_type=return_type, **kwargs)
@@ -360,13 +308,14 @@ def common_post(path, data=None, service_name=None, namespace="public", clusters
         raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
 
 
-def common_put(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None, **kwargs):
-    base_url = tornado.options.options.data_server
+def common_put(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None,
+               request_type="request", **kwargs):
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
-    if tornado.options.options.request_type == "request":
+        connect_config = options.connect_config
+    if request_type == "request":
         res = sync_put(path=path, params=params, data=data, json=json,
                        base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config, **kwargs)
         return res
@@ -375,13 +324,13 @@ def common_put(path, params=None, data=None, json=None, pack=False, return_type=
 
 
 def common_patch(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None,
-                 **kwargs):
-    base_url = tornado.options.options.data_server
+                 request_type="request", **kwargs):
+    base_url = options.data_server
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
-    if tornado.options.options.request_type == "request":
+        connect_config = options.connect_config
+    if request_type == "request":
         res = sync_patch(path=path, params=params, data=data, json=json,
                          base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config, **kwargs)
         return res
@@ -390,13 +339,13 @@ def common_patch(path, params=None, data=None, json=None, pack=False, return_typ
 
 
 def common_delete(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None,
-                  **kwargs):
-    base_url = tornado.options.options.data_server
+                  request_type="request", **kwargs):
+    base_url = options.data_server
     if connect_config is None:
-        connect_config = tornado.options.options.connect_config
+        connect_config = options.connect_config
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
-    if tornado.options.options.request_type == "request":
+    if request_type == "request":
         res = sync_delete(path=path, params=params, data=data, json=json,
                           base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config,
                           **kwargs)
